@@ -1,20 +1,21 @@
 from random import choice
 import os
-import subprocess
-import urllib2
-import shutil
 import logging
 import re
 
 from zc.buildout import UserError
 import zc.recipe.egg
-import setuptools
 
 from boilerplate import script_template, versions
 
 
 class Recipe(object):
     def __init__(self, buildout, name, options):
+        # The use of version is deprecated.
+        if 'version' in options:
+            raise UserError('The version option is deprecated. '
+                            'Read about the change on '
+                            'http://pypi.python.org/pypi/djangorecipe')
         self.log = logging.getLogger(name)
         self.egg = zc.recipe.egg.Egg(buildout, options['recipe'], options)
 
@@ -38,52 +39,18 @@ class Recipe(object):
         else:
             options.setdefault('extra-paths', options.get('pythonpath', ''))
 
-        # Usefull when using archived versions
-        buildout['buildout'].setdefault(
-            'download-cache',
-            os.path.join(buildout['buildout']['directory'],
-                         'downloads'))
-
         # mod_wsgi support script
         options.setdefault('wsgi', 'false')
         options.setdefault('fcgi', 'false')
         options.setdefault('wsgilog', '')
         options.setdefault('logfile', '')
 
-        # only try to download stuff if we aren't asked to install from cache
-        self.install_from_cache = self.buildout['buildout'].get(
-            'install-from-cache', '').strip() == 'true'
-
     def install(self):
         location = self.options['location']
         base_dir = self.buildout['buildout']['directory']
 
         project_dir = os.path.join(base_dir, self.options['project'])
 
-        download_dir = self.buildout['buildout']['download-cache']
-        if not os.path.exists(download_dir):
-            os.mkdir(download_dir)
-
-        version = self.options['version']
-        # Remove a pre-existing installation if it is there
-        if os.path.exists(location):
-            shutil.rmtree(location)
-
-        if self.is_svn_url(version):
-            self.install_svn_version(version, download_dir, location,
-                                     self.install_from_cache)
-        else:
-            tarball = self.get_release(version, download_dir)
-            # Extract and put the dir in its proper place
-            self.install_release(version, download_dir, tarball, location)
-
-        self.options['setup'] = location
-        development = zc.recipe.egg.Develop(self.buildout,
-                                            self.options['recipe'],
-                                            self.options)
-        development.install()
-        del self.options['setup']
-
         extra_paths = self.get_extra_paths()
         requirements, ws = self.egg.working_set(['djangorecipe'])
 
@@ -110,58 +77,6 @@ class Recipe(object):
 
         return script_paths + [location]
 
-    def install_svn_version(self, version, download_dir, location,
-                            install_from_cache):
-        svn_url = self.version_to_svn(version)
-        download_location = os.path.join(
-            download_dir, 'django-' +
-            self.version_to_download_suffix(version))
-        if not install_from_cache:
-            if os.path.exists(download_location):
-                if self.svn_update(download_location, version):
-                    raise UserError(
-                        "Failed to update Django; %s. "
-                        "Please check your internet connection." % (
-                            download_location))
-            else:
-                self.log.info("Checking out Django from svn: %s" % svn_url)
-                cmd = 'svn co \'%s\' \'%s\'' % (svn_url, download_location)
-                if not self.buildout['buildout'].get('verbosity'):
-                    cmd += ' -q'
-                if self.command(cmd):
-                    raise UserError("Failed to checkout Django. "
-                                    "Please check your internet connection.")
-        else:
-            self.log.info("Installing Django from cache: " + download_location)
-
-        shutil.copytree(download_location, location)
-
-    def install_release(self, version, download_dir, tarball, destination):
-        extraction_dir = os.path.join(download_dir, 'django-archive')
-        setuptools.archive_util.unpack_archive(tarball, extraction_dir)
-        # Lookup the resulting extraction dir instead of guessing it
-        # (Django releases have a tendency not to be consistend here)
-        untarred_dir = os.path.join(extraction_dir,
-                                    os.listdir(extraction_dir)[0])
-        shutil.move(untarred_dir, destination)
-        shutil.rmtree(extraction_dir)
-
-    def get_release(self, version, download_dir):
-        tarball = os.path.join(download_dir, 'django-%s.tar.gz' % version)
-
-        # Only download when we don't yet have an archive
-        if not os.path.exists(tarball):
-            download_url = 'http://www.djangoproject.com/download/%s/tarball/'
-            self.log.info("Downloading Django from: %s" % (
-                    download_url % version))
-
-            tarball_f = open(tarball, 'wb')
-            f = urllib2.urlopen(download_url % version)
-            tarball_f.write(f.read())
-            tarball_f.close()
-            f.close()
-        return tarball
-
     def create_manage_script(self, extra_paths, ws):
         project = self.options.get('projectegg', self.options['project'])
         return zc.buildout.easy_install.scripts(
@@ -191,15 +106,19 @@ class Recipe(object):
 
     def create_project(self, project_dir):
         os.makedirs(project_dir)
-        version = self.options['version']
 
-        # Check the version to deploy the corresponding boilerplate
-        # settings/urlsconf.
-        version_re = re.compile("\d+\.\d+")
-        match = version_re.match(version)
-        if match:
-            version = version_re.match(version).group()
-        config = versions.get(version, versions['trunk'])
+        # Find the current Django versions in the buildout versions.
+        # Assume the newest Django when no version is found.
+        version = None
+        b_versions = self.buildout.get('versions')
+        if b_versions:
+            django_version = b_versions.get('django')
+            if django_version:
+                version_re = re.compile("\d+\.\d+")
+                match = version_re.match(django_version)
+                version = match and match.group()
+
+        config = versions.get(version, versions['Newest'])
 
         template_vars = {'secret': self.generate_secret()}
         template_vars.update(self.options)
@@ -256,36 +175,6 @@ class Recipe(object):
         zc.buildout.easy_install.script_template = _script_template
         return scripts
 
-    def is_svn_url(self, version):
-        # Search if there is http/https/svn or svn+[a tunnel identifier] in the
-        # url or if the trunk marker is used, all indicating the use of svn
-        svn_version_search = re.compile(
-            r'^(http|https|svn|svn\+[a-zA-Z-_]+)://|^(trunk)$').search(version)
-        return svn_version_search is not None
-
-    def version_to_svn(self, version):
-        if version == 'trunk':
-            return 'http://code.djangoproject.com/svn/django/trunk/'
-        else:
-            return version
-
-    def version_to_download_suffix(self, version):
-        if version == 'trunk':
-            return 'svn'
-        return [p for p in version.split('/') if p][-1]
-
-    def svn_update(self, path, version):
-        command = 'svn up'
-        revision_search = re.compile(r'@([0-9]*)$').search(
-            self.options['version'])
-
-        if revision_search is not None:
-            command += ' -r ' + revision_search.group(1)
-        self.log.info("Updating Django from svn")
-        if not self.buildout['buildout'].get('verbosity'):
-            command += ' -q'
-        return self.command(command, cwd=path)
-
     def get_extra_paths(self):
         extra_paths = [self.options['location'],
                        self.buildout['buildout']['directory'],
@@ -311,11 +200,6 @@ class Recipe(object):
         return extra_paths
 
     def update(self):
-        newest = self.buildout['buildout'].get('newest') != 'false'
-        if newest and not self.install_from_cache and \
-                self.is_svn_url(self.options['version']):
-            self.svn_update(self.options['location'], self.options['version'])
-
         extra_paths = self.get_extra_paths()
         requirements, ws = self.egg.working_set(['djangorecipe'])
         # Create the Django management script
@@ -327,14 +211,6 @@ class Recipe(object):
         # Make the wsgi and fastcgi scripts if enabled
         self.make_scripts(extra_paths, ws)
 
-    def command(self, cmd, **kwargs):
-        output = subprocess.PIPE
-        if self.buildout['buildout'].get('verbosity'):
-            output = None
-        command = subprocess.Popen(
-            cmd, shell=True, stdout=output, **kwargs)
-        return command.wait()
-
     def create_file(self, file, template, options):
         if os.path.exists(file):
             return
